#include "video.h"

#include "json/layout.h"
#include "util/dir.h"

#include <stdlib.h>
#include <string.h>
#include <libgen.h>

#define OBJ_TYPE struct video
static struct json_object_field video_layout[] = {
	JSON_FIELD_STRING( video_file, true ),
	JSON_FIELD_STRING( title, false ),
	JSON_FIELD_STRING( description, false ),

	JSON_FIELD_STRING( original_url, false ),

	JSON_FIELD_INTEGER( owner_id, true ),

	JSON_FIELD_END
};
#undef OBJ_TYPE

struct video* video_new()
{
	struct video* v;
	v = malloc(sizeof(*v));
	memset(v,0,sizeof(*v));

	return v;
}

static const char* get_video_data_filename( int id, char* buffer, int buffer_size )
{
	int ones      = id % 1000; id /= 1000;
	int thousands = id % 1000; id /= 100;
	int millions  = id % 1000;

	snprintf( buffer, buffer_size, "data/videos/%03dm/%03dk/%03d.json", millions, thousands, ones );
	return buffer;
}

struct video* video_from_id( int id )
{
	if( id <= 0 ) { return NULL; };

	char buffer[512];
	const char* filename = get_video_data_filename( id, buffer, sizeof(buffer) );
	//printf( "Using filename %s\n", filename );

	struct video* v = video_new();

	if( !json_read_object_layout_from_file( filename, video_layout, v ) ) {
		//printf( "Unable to read file\n" );
		video_free(v);
		return NULL;
	}

	return v;
}

void video_free( struct video* v )
{
	if( !v ) { return; }

	free(v);
}

void video_list_free( struct video_list* vl )
{
	for( int i = 0; i < vl->count; ++i ) {
		video_free( vl->items[i] );
	}

	free( vl->items );
	memset(vl,0,sizeof(*vl));
}

